==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Plot/resources/translations/Plot_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="../../InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Ferramentas de edición de trazado</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Trazado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="../../PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Configurar eixos</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Configurar os parámetros dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="../../PlotGui.py" line="109"/>
      <source>Show/Hide grid</source>
      <translation>Amosar/Agochar grella</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="112"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Amosar/Agochar grella no trazado escolmado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="../../PlotGui.py" line="152"/>
      <source>Set labels</source>
      <translation>Estabelecer etiquetas</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="155"/>
      <source>Set title and axes labels</source>
      <translation>Estabelecer títulos e etiquetas dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="../../PlotGui.py" line="135"/>
      <source>Show/Hide legend</source>
      <translation>Amosar/Agochar lenda</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="138"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Amosar/Agochar lenda no trazado escolmado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="../../PlotGui.py" line="169"/>
      <source>Set positions and sizes</source>
      <translation>Estabelecer tamaños e posicións</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="172"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Estabelecer tamaños e posicións de etiquetas e lendas</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="../../PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Gardar trazado</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Gardar o trazado como ficheiro de imaxe</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="../../PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Configurar series</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurar o estilo de deseño en serie e etiqueta</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Configurar eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
      <source>Active axes</source>
      <translation>Eixes activos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
      <source>Apply to all axes</source>
      <translation>Aplicar a tódolos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
      <source>Dimensions</source>
      <translation>Dimensións</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
      <source>X axis position</source>
      <translation>Posición do eixo X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
      <source>Y axis position</source>
      <translation>Posición do eixo Y</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
      <source>Scales</source>
      <translation>Escalas</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
      <source>Index of the active axes</source>
      <translation>Índice de eixos activos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
      <source>Add new axes to the plot</source>
      <translation>Engadir novos eixos o trazado</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
      <source>Remove selected axes</source>
      <translation>Rexeitar os eixos escolmados</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Marcalo para aplicar transformacións a tódolos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
      <source>Left bound of axes</source>
      <translation>Límite esquerdo dos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
      <source>Right bound of axes</source>
      <translation>Límite dereito dos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
      <source>Bottom bound of axes</source>
      <translation>Límite inferior dos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
      <source>Top bound of axes</source>
      <translation>Límite superior dos eixos</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
      <source>Outward offset of X axis</source>
      <translation>Desprazamento cara fóra do eixo X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
      <source>Outward offset of Y axis</source>
      <translation>Desprazamento cara fóra do eixo Y</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
      <source>X axis scale autoselection</source>
      <translation>Auto-escolma da escala do eixo X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
      <source>Y axis scale autoselection</source>
      <translation>Auto-escolma da escala do eixo Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="../../Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>Non se atopou matplotlib, polo que non se pode cargar o módulo de trazado</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>Non se atopou matplotlib. O módulo de trazado será inhabilitado</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Debe escolmar un documento de trazado a fin de gardalo</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Os eixos 0 non se poden desbotar</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>A grella debe ser activada enriba dun documento trazado</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="125"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>A lenda debe ser activada enriba dun documento trazado</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Estabelecer etiquetas</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
      <source>Active axes</source>
      <translation>Eixes activos</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
      <source>Title</source>
      <translation>Título</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
      <source>X label</source>
      <translation>Etiqueta X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
      <source>Y label</source>
      <translation>Etiqueta Y</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
      <source>Index of the active axes</source>
      <translation>Índice de eixos activos</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
      <source>Title (associated to active axes)</source>
      <translation>Título (vencellado ó eixo activo)</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
      <source>Title font size</source>
      <translation>Tamaño de fonte do título</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
      <source>X axis title</source>
      <translation>Título do Eixe X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
      <source>X axis title font size</source>
      <translation>Tamaño da fonte do título do eixo X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
      <source>Y axis title</source>
      <translation>Título do Eixe Y</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
      <source>Y axis title font size</source>
      <translation>Tamaño da fonte do título do eixo Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Estabelecer tamaños e posicións</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
      <source>Position</source>
      <translation type="unfinished">Position</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
      <source>Size</source>
      <translation>Tamaño</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
      <source>X item position</source>
      <translation>Posición do elemento en X</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
      <source>Y item position</source>
      <translation>Posición do elemento en Y</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
      <source>Item size</source>
      <translation>Tamaño do elemento</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
      <source>List of modifiable items</source>
      <translation>Lista de elementos modificables</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="127"/>
      <source>Save figure</source>
      <translation>Gardar figura</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="131"/>
      <source>Inches</source>
      <translation>Polgadas</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="136"/>
      <source>Dots per Inch</source>
      <translation>Puntos por polgada</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="141"/>
      <source>Output image file path</source>
      <translation>Camiño do ficheiro de saída da imaxe</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="146"/>
      <source>Show a file selection dialog</source>
      <translation>Amosa un diálogo de escolma de ficheiro</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="151"/>
      <source>X image size</source>
      <translation>Tamaño da imaxe en X</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="156"/>
      <source>Y image size</source>
      <translation>Tamaño da imaxe en Y</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="161"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Puntos por punto, xunto co tamaño vai definir a resolución da imaxe de saída</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
      <source>No label</source>
      <translation>Sen título</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
      <source>Line style</source>
      <translation>Estilo de liña</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
      <source>Marker</source>
      <translation>Marcador</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Configurar series</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
      <source>List of available series</source>
      <translation>Listaxe de series dispoñíbeis</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
      <source>Line title</source>
      <translation>Título de liña</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
      <source>Marker style</source>
      <translation>Estilo de marcador</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
      <source>Line width</source>
      <translation>Largura da liña</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
      <source>Marker size</source>
      <translation>Tamaño do marcador</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
      <source>Line and marker color</source>
      <translation>Cor da liña e mais do marcador</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
      <source>Remove series</source>
      <translation>Eliminar series</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Se está marcado, as series non se amosarán na lenda</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
      <source>Removes this series</source>
      <translation>Borrar estas series</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Plot/resources/translations/Plot_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="gl" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="46"/>
      <source>Plot edition tools</source>
      <translation>Ferramentas de edición de trazado</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="49"/>
      <source>Plot</source>
      <translation>Trazado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure axes</source>
      <translation>Configurar eixos</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="68"/>
      <source>Configure the axes parameters</source>
      <translation>Configurar os parámetros dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="112"/>
      <source>Show/Hide grid</source>
      <translation>Amosar/Agochar grella</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="115"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Amosar/Agochar grella no trazado escolmado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="155"/>
      <source>Set labels</source>
      <translation>Estabelecer etiquetas</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="158"/>
      <source>Set title and axes labels</source>
      <translation>Estabelecer títulos e etiquetas dos eixos</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="138"/>
      <source>Show/Hide legend</source>
      <translation>Amosar/Agochar lenda</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="141"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Amosar/Agochar lenda no trazado escolmado</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="172"/>
      <source>Set positions and sizes</source>
      <translation>Estabelecer tamaños e posicións</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="175"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Estabelecer tamaños e posicións de etiquetas e lendas</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save plot</source>
      <translation>Gardar trazado</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="51"/>
      <source>Save the plot as an image file</source>
      <translation>Gardar o trazado como ficheiro de imaxe</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series</source>
      <translation>Configurar series</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="87"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurar o estilo de deseño en serie e etiqueta</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Configure axes</source>
      <translation>Configurar eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Active axes</source>
      <translation>Eixes activos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="216"/>
      <source>Apply to all axes</source>
      <translation>Aplicar a tódolos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Dimensions</source>
      <translation>Dimensións</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="224"/>
      <source>X axis position</source>
      <translation>Posición do eixo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>Y axis position</source>
      <translation>Posición do eixo Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="204"/>
      <source>Scales</source>
      <translation>Escalas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="232"/>
      <source>Index of the active axes</source>
      <translation>Índice de eixos activos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="237"/>
      <source>Add new axes to the plot</source>
      <translation>Engadir novos eixos o trazado</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="242"/>
      <source>Remove selected axes</source>
      <translation>Rexeitar os eixos escolmados</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="247"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Marcalo para aplicar transformacións a tódolos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="252"/>
      <source>Left bound of axes</source>
      <translation>Límite esquerdo dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Right bound of axes</source>
      <translation>Límite dereito dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="262"/>
      <source>Bottom bound of axes</source>
      <translation>Límite inferior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="267"/>
      <source>Top bound of axes</source>
      <translation>Límite superior dos eixos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="272"/>
      <source>Outward offset of X axis</source>
      <translation>Desprazamento cara fóra do eixo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="277"/>
      <source>Outward offset of Y axis</source>
      <translation>Desprazamento cara fóra do eixo Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="282"/>
      <source>X axis scale autoselection</source>
      <translation>Auto-escolma da escala do eixo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Y axis scale autoselection</source>
      <translation>Auto-escolma da escala do eixo Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="47"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>Non se atopou matplotlib, polo que non se pode cargar o módulo de trazado</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="58"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>Non se atopou matplotlib. O módulo de trazado será inhabilitado</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="48"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Debe escolmar un documento de trazado a fin de gardalo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="346"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Os eixos 0 non se poden desbotar</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="101"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>A grella debe ser activada enriba dun documento trazado</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="129"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>A lenda debe ser activada enriba dun documento trazado</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Set labels</source>
      <translation>Estabelecer etiquetas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Active axes</source>
      <translation>Eixes activos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="146"/>
      <source>Title</source>
      <translation>Título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>X label</source>
      <translation>Etiqueta X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Y label</source>
      <translation>Etiqueta Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Índice de eixos activos</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Título (vencellado ó eixo activo)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Title font size</source>
      <translation>Tamaño de fonte do título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="173"/>
      <source>X axis title</source>
      <translation>Título do Eixe X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>X axis title font size</source>
      <translation>Tamaño da fonte do título do eixo X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="183"/>
      <source>Y axis title</source>
      <translation>Título do Eixe Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="188"/>
      <source>Y axis title font size</source>
      <translation>Tamaño da fonte do título do eixo Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="124"/>
      <source>Set positions and sizes</source>
      <translation>Estabelecer tamaños e posicións</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="129"/>
      <source>Position</source>
      <translation type="unfinished">Position</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="134"/>
      <source>Size</source>
      <translation>Tamaño</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Posición do elemento en X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Y item position</source>
      <translation>Posición do elemento en Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Item size</source>
      <translation>Tamaño do elemento</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>List of modifiable items</source>
      <translation>Lista de elementos modificables</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Save figure</source>
      <translation>Gardar figura</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="137"/>
      <source>Inches</source>
      <translation>Polgadas</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Dots per Inch</source>
      <translation>Puntos por polgada</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="147"/>
      <source>Output image file path</source>
      <translation>Camiño do ficheiro de saída da imaxe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Show a file selection dialog</source>
      <translation>Amosa un diálogo de escolma de ficheiro</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Tamaño da imaxe en X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Y image size</source>
      <translation>Tamaño da imaxe en Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Puntos por punto, xunto co tamaño vai definir a resolución da imaxe de saída</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>No label</source>
      <translation>Sen título</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="192"/>
      <source>Line style</source>
      <translation>Estilo de liña</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Configure series</source>
      <translation>Configurar series</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="177"/>
      <source>List of available series</source>
      <translation>Listaxe de series dispoñíbeis</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="182"/>
      <source>Line title</source>
      <translation>Título de liña</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="197"/>
      <source>Marker style</source>
      <translation>Estilo de marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Line width</source>
      <translation>Largura da liña</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="207"/>
      <source>Marker size</source>
      <translation>Tamaño do marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Line and marker color</source>
      <translation>Cor da liña e mais do marcador</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Remove series</source>
      <translation>Eliminar series</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Se está marcado, as series non se amosarán na lenda</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="217"/>
      <source>Removes this series</source>
      <translation>Borrar estas series</translation>
    </message>
  </context>
</TS>
